function out=hedgeLineagePlot2(data,N,colorMap)
%hedgeLineagePlot2 makes a pretty plot of fly lineages and fates based on
%the fly data matrix produced by hedgeSim4.m. Used to make Figure 2 of the
%paper. Only works with seasons of length 214, the paper standard.
%=========================================================================
% Usage:
% out=hedgeLineagePlot2(data,N,colorMap)
% Inputs:
%       * data = .data object from the output of hedgeSim4.m
%       * N = max number of flies to be shown in figure
%       * colorMap = color scheme for lineage branches (from kbcy.mat) -
%           works with 64 color colormaps
% Output, out = plotting data for the lineage processed last (isn't used for
%       anything, honestly)

%establish some indices
N0=9;
N1=11;
N2=12;
NhowDeath=10;

%size of Markers for death events
marSize=6;

% clean up some of the orignal fly data matrix encoding
data(1:100,6)=0;                            % all seed flies have an effective birth date of 0 for these purposes
data(1:100,N0)=1:100;                       % seed flies should have a 1...100 index number (this line seems redundant)
data=[data data(:,N0)];                     % tack the index column onto data as a new column
data(isnan(data))=214;                      % replace all remaining NaNs (which should only be in the death date slot of flies that didn't die) with 214 for these purposes.
data=[data (1:size(data,1))'];              % tack on an index column for the entire matrix

% replace the parental ID # of each fly with its grand parental ID#, etc,
% until all flies have their lineage marked back to one of the seed
% population flies. column N1 contains this back-calculated lineage tag.
while max(data(:,N1))>100
    for i=1:size(data,1)
        if data(i,N1) > 100
            data(i,N1)=data(data(i,N1),N0);
        end
    end
end

%calculate the number of progeny derived from each seed fly
progCounts=zeros(100,1);
for i=1:100
    progCounts(i)=sum(data(:,N1)==i);
end

%open figure
figure;
hold on;

%plotting parameter allocating space to each lineage
offSet=0;

%start adding flies, one lineage at a time until target number of lineages
%to plot (N) is surpassed. 
i=1;
while offSet<N && i<=100
    
    %extract descendant flies of next seed pop fly.
    dataSub=data(data(:,N1)==i,:);
    
    %replace original parental ID#s with ID#s indexed to this lineage submatrix.
    for j=1:size(dataSub,1)
        dataSub(j,N0)=find(dataSub(:,N2)==dataSub(j,N0));
    end
    
    %renumber fly index within this lineage submatrix.
    dataSub(:,N2)=(1:size(dataSub,1))';
    
    %how many flies in this lineage.
    subN=size(dataSub,1);
    
    % accumulate details for plotting each progeny, starting with seed fly
    % This step sets the order in which fly branches will appear in the
    % tree.
    dataNew=dataSub(1,:);
    for j=2:subN %for each progeny fly,
        newLine=dataSub(j,:);                       %take its data
        wherePar=find(dataNew(:,N2)==newLine(N0));  %get the index of its parent
        if wherePar==1                              %if a direct descendent of seed
            partA=[];                               %do nothing
        else                                        %otherwise
            partA=dataNew(1:wherePar-1,:);          %get all the current detail matrix up to the parent fly
        end
        partC=dataNew(wherePar:end,:);              %get all the current detail matrix including and after the parent fly
        dataNew=[partA;newLine;partC];              %reassemble parts, inserting fly under consideration after its parent, and before everyone else
    end
    
    % for all the flies in this lineage, plot them
    for j=1:size(dataNew,1)
        % get line color from photo preference index (1) and colormap
        col=colorMap(min([64, ceil(64*dataNew(j,1))]),:);
        %draw a line from the birthdate to the death date along X 
        plot([dataNew(j,6) dataNew(j,7)],[j j]+offSet,'Color',col);
        %draw a line from the parental line to this line, under constant X = the birthdate.
        plot([dataNew(j,6) dataNew(j,6)],[j find(dataNew(:,N2)==dataNew(j,N0))]+offSet,'Color',col);
        
        %give the line a death symbol, depending on manner
        if dataNew(j,NhowDeath)==1 % if death by random circumstance (gray)
            scatter(dataNew(j,7),j+offSet,marSize,[0.5 0.5 0.5],'filled');      %dot on the fly branch line
            scatter(dataNew(j,7),-10+rand(),marSize,[0.5 0.5 0.5],'filled');    %dot projected below the graph, with random dither
        elseif dataNew(j,NhowDeath)==2 %if death by old age (red)
            scatter(dataNew(j,7),j+offSet,marSize,[1 0 0],'filled');            %dot on the fly branch line
            scatter(dataNew(j,7),-20+rand(),marSize,[1 0 0],'filled');          %dot projected below the graph, with random dither
        end
    end
    
    %increment plotting offset by the number of flies just plotted
    offSet=offSet+subN;
    
    %index++
    i=i+1;
end

%set nice plot limits and output the most recently processed lineage.
ylim([-25 offSet+1])
out=dataNew;
